@@ -18,9 +18,12 @@ from .parameters.constraints import Constraint
 # Requirements
 from .requirements.Sample import Sample
 from .requirements.Source import Moderator
+from .requirements.MCPL_source import MCPL_source
+from .requirements.ESS_Butterfly_source import ESS_Butterfly
 
 # guide modules
 from .elements.Element_gap import Gap
+from .elements.Element_kink import Kink
 from .elements.Element_slit import Slit
 from .elements.Element_straight import Straight
 from .elements.Element_elliptic import Elliptic
