@@ -134,11 +134,44 @@ class Element:
         self.start_point_parameter = None
         self.next_start_point_parameter = None
 
+        self.element_length = None
+        self.length_parameter_name = None
+
         self.reference_component_name = None
         self.end_component_name = name + "_end_point"
 
         self.owner = None
 
+    def get_length_name(self):
+        """
+        Provides length name, ensures this variable is available in instrument
+
+        When adding components describing the GuideElement to the instrument
+        file, the length will most probably be needed. This method adds code
+        to the instrument file that declares a length variable and calculates
+        it from the change points that is used as instrument inputs. It then
+        returns the name of the variable, which can be used when setting up
+        the McStas components. It avoids adding the same parameter more than
+        once by checking if it has already been added.
+        """
+
+        previous_cb_name = self.start_point_parameter.name
+        next_cb_name = self.next_start_point_parameter.name
+        length_var_name = self.name + "_length"
+
+        current_variables = [x.name for x in self.current_instrument.declare_list if hasattr(x, "name")]
+        if length_var_name not in current_variables:
+            self.current_instrument.add_declare_var("double", length_var_name)
+            self.current_instrument.append_initialize(
+                length_var_name + " = " + next_cb_name + " - " + previous_cb_name + ";")
+
+        self.length_parameter_name = length_var_name
+
+        return length_var_name
+
+    def calculate_length(self):
+        self.element_length = self.next_start_point_parameter.get_value() - self.start_point_parameter.get_value()
+
     def set_owner(self, owner):
         """
         Sets the owner of this Element
@@ -243,6 +276,8 @@ class GuideElement(Element):
         self.current_instrument = None
         self.current_parameters = None
 
+
+
         super().__init__(name, length=length, start_point=start_point, **kwargs)
     
     def setup_instrument_and_parameters(self, instrument, instrument_parameters):
@@ -302,32 +337,6 @@ class GuideElement(Element):
 
         self.end_width = end_width
         self.end_height = end_height
-    
-    def get_length_name(self):
-        """
-        Provides length name, ensures this variable is available in instrument
-
-        When adding components describing the GuideElement to the instrument
-        file, the length will most probably be needed. This method adds code
-        to the instrument file that declares a length variable and calculates
-        it from the change points that is used as instrument inputs. It then
-        returns the name of the variable, which can be used when setting up
-        the McStas components.
-        """
-
-        # This can go into a method somewhere, very normal operation
-        previous_cb_name = self.start_point_parameter.name
-        next_cb_name = self.next_start_point_parameter.name
-        length_var_name = self.name + "_length"
-        self.current_instrument.add_declare_var("double", length_var_name)
-        self.current_instrument.append_initialize(length_var_name + " = " + next_cb_name + " - " + previous_cb_name + ";")
-        
-        self.length_parameter = length_var_name
-    
-        return length_var_name
-
-    def calculate_length(self):
-        self.element_length = self.next_start_point_parameter.get_value() - self.start_point_parameter.get_value()
 
     def write_to_log_base(self, file):
         """
@@ -364,7 +373,7 @@ class GuideElement(Element):
     def copy_component(self, name, destination):
         this_file_path = os.path.abspath(__file__)
         this_directory = os.path.split(this_file_path)[0]
-        component_path = os.path.join(this_directory, "..", "..", "McStas_components", name)
+        component_path = os.path.join(this_directory, "..", "McStas_components", name)
         destination_path = os.path.join(destination, name)
 
         shutil.copyfile(component_path, destination_path)
