@@ -1,4 +1,7 @@
+import numpy as np
+
 from guide_bot.base_elements import guide_elements
+from guide_bot.base_elements.guide_elements import PositionAndRotation
 
 class Gap(guide_elements.GuideElement):
     """
