@@ -269,9 +269,12 @@ class SourceAnalysis:
         self.path = path
         self.data_folders = []
         self.runs = {}
-
         self.find_runs()
 
+        self.log_file = None
+        self.guide_log_file = None
+        self.find_logs()
+
     def find_runs(self):
         folders = os.listdir(self.path)
 
@@ -302,6 +305,14 @@ class SourceAnalysis:
                 run = SingleRun(folder)
                 self.runs[run.name] = run
 
+    def find_logs(self):
+        files = os.listdir(self.path)
+        for file in files:
+            if file.endswith(".guide_log"):
+                self.guide_log_file = os.path.join(self.path, file)
+            if file.endswith(".log"):
+                self.log_file = os.path.join(self.path, file)
+
     def show_runs(self):
         for run in self.runs:
             print(self.runs[run])
@@ -508,6 +519,17 @@ class ScanOverview:
 
         return os.path.abspath(os.path.join(self.project_path, guide_name, guide_name + state_string))
 
+    def get_optimization_base_data_location(self, guide_name, indices):
+        if type(guide_name) is int:
+            guide_names = self.get_guide_names()
+            guide_name = guide_names[guide_name]
+
+        state_string = self.get_state_string(guide_name, indices)
+
+        return os.path.abspath(os.path.join(self.project_path, guide_name,
+                                            guide_name + state_string + "_main_optimization",
+                                            guide_name + state_string))
+
     def get_data_location(self, guide_name, indices, analysis_moderator=None):
         if type(guide_name) is int:
             guide_names = self.get_guide_names()
@@ -575,25 +597,34 @@ class ScanOverview:
         self.log[guide] = {}
 
         scan = np.ndindex(*self.get_shape())
-        while (True):
+        while True:
             try:
                 state = next(scan)
             except StopIteration:
                 break
 
             self.log[guide][state] = {}
+            self.log[guide][state]["main"] = {}
 
             expected_guide_log_path = self.get_base_data_location(guide, state) + ".guide_log"
             if os.path.isfile(expected_guide_log_path):
-                self.log[guide][state]["guide_log"] = expected_guide_log_path
+                self.log[guide][state]["main"]["guide_log"] = expected_guide_log_path
             else:
-                self.log[guide][state]["guide_log"] = None
+                expected_guide_log_path = self.get_optimization_base_data_location(guide, state) + ".guide_log"
+                if os.path.isfile(expected_guide_log_path):
+                    self.log[guide][state]["main"]["guide_log"] = expected_guide_log_path
+                else:
+                    self.log[guide][state]["main"]["guide_log"] = None
 
             expected_log_path = self.get_base_data_location(guide, state) + "_optimization.log"
             if os.path.isfile(expected_log_path):
-                self.log[guide][state]["log"] = expected_log_path
+                self.log[guide][state]["main"]["log"] = expected_log_path
             else:
-                self.log[guide][state]["log"] = None
+                expected_log_path = self.get_optimization_base_data_location(guide, state) + "_optimization.log"
+                if os.path.isfile(expected_log_path):
+                    self.log[guide][state]["main"]["log"] = expected_log_path
+                else:
+                    self.log[guide][state]["main"]["log"] = None
 
             self.data[guide][state] = {}
 
@@ -602,10 +633,17 @@ class ScanOverview:
                 path = self.get_data_location(guide, state, analysis_moderator=mod)
 
                 if self.path_is_data_directory(path):
-                    self.data[guide][state][mod] = SourceAnalysis(path)
+                    source_analysis = SourceAnalysis(path)
+                    self.data[guide][state][mod] = source_analysis
+                    self.log[guide][state][mod] = {}
+                    self.log[guide][state][mod]["log"] = source_analysis.log_file
+                    self.log[guide][state][mod]["guide_log"] = source_analysis.guide_log_file
                     any_success = True
                 else:
                     self.data[guide][state][mod] = None
+                    self.log[guide][state][mod] = {}
+                    self.log[guide][state][mod]["log"] = None
+                    self.log[guide][state][mod]["guide_log"] = None
 
             if any_success:
                 if guide not in self.succesful_indices:
