@@ -2,8 +2,9 @@ import copy
 import os
 import dill
 import yaml
+import shutil
 
-from _version import __version__
+from .._version import __version__
 from guide_bot.parameters import instrument_parameters as ipars
 from guide_bot.parameters import instrument_parameter_container as ipars_container
 import guide_bot.requirements.requirement_parameters as rpars
@@ -351,6 +352,87 @@ class Guide:
         return string
 
 
+class DataCollector:
+    def __init__(self, data_abs_path):
+        """
+        Ensures data is copied to project datafolder
+        """
+        if not os.path.exists(data_abs_path):
+            raise RunTimeError("Didn't find data folder")
+
+        self.data_abs_path = data_abs_path
+
+        data_folder_name = os.path.split(self.data_abs_path)[1]
+        # All runs happens to levels under data folder
+        self.data_relative_path = os.path.join("..", "..", data_folder_name)
+
+        self.copied_original_paths = []
+        self.copied_final_paths = []
+
+    def collect(self, parameters_object):
+        """
+        Collects datafiles for parameter object
+
+        Any parameter that has the is_filename set to True at creation will
+        be handled by this method. The corresponding file is copied to the
+        data_abs_path in the DataCollector object, and the filename parameter
+        is updated with a new path that points to the copied file. In this way
+        the user can copy the project to a cluster without worrying about
+        files the simulation depends on, and it is saved for reproducibility.
+        For this reason the new path is a relative path so the project folder
+        can be moved without breaking absolute paths.
+        Files are only copied once, if two datafiles have the same name, it
+        will only be copied once, which is a potential problem.
+
+        Parameters
+        ----------
+
+        parameters_object : Parameters object
+            Parameters object that may have filenames included
+        """
+
+        for filename_par_name in parameters_object.get_filename_pars():
+            self.collect_file(parameters_object, filename_par_name)
+
+    def collect_file(self, parameters_object, filename_par_name):
+        """
+        Checks if a file has already been copied, if not copies it
+
+        Parameters
+        ----------
+
+        parameters_object : Parameters object
+            Parameters object that may have filenames included
+
+        filename_par_name : str
+            Parameter name that correspond to a filename
+        """
+
+        current_file_path = parameters_object[filename_par_name]
+
+        # Check file has not already been copied
+        if current_file_path in self.copied_original_paths:
+            return
+
+        if current_file_path in self.copied_final_paths:
+            return
+
+        if not os.path.exists(current_file_path):
+            raise RunTimeError("File didn't exist!")
+
+        # Perform a copy operation
+        filename = os.path.split(current_file_path)[1]
+        new_abs_path = os.path.join(self.data_abs_path, filename)
+        shutil.copyfile(current_file_path, new_abs_path)
+
+        # Set new relative path
+        new_path = os.path.join(self.data_relative_path, filename)
+        parameters_object[filename_par_name] = '"' + new_path + '"'
+
+        self.copied_original_paths.append(current_file_path)
+        self.copied_final_paths.append(new_path)
+
+
 class Project:
     """
     Main logic for performing a guide_bot run with any number of guides
@@ -490,6 +572,15 @@ class Project:
         total_configs = n_sample_configs*n_mod_configs*len(self.guides)
         string += "Total optimizations to be performed: " + str(total_configs) + "\n"
 
+        string += "\n"
+
+        if self.analysis_moderators is None:
+            string += "No analysis moderators"
+        else:
+            string += "Analysis moderators: \n"
+            for moderator in self.analysis_moderators:
+                string += "  " + moderator.get_name() + "\n"
+
         return string
 
     def package_single(self, guide, scan_name):
@@ -575,6 +666,24 @@ class Project:
         self.original_wd = os.getcwd()
         self.base_folder = os.path.join(self.original_wd, self.name)
 
+        # Create datafiles folder for project
+        data_path = os.path.join(self.name, "input_data_folder")
+        try:
+            os.mkdir(data_path)
+        except OSError:
+            raise RuntimeError("Could not create input_data_folder in guide_bot project!")
+        self.abs_data_path = os.path.abspath(data_path)
+
+        # copy data files needed for all scan states
+        data_collector = DataCollector(self.abs_data_path)
+        scan.reset_configuration()
+        while scan.next_state():
+            data_collector.collect(self.sample.parameters)
+            data_collector.collect(self.moderator.parameters)
+
+            for analysis_moderator in self.analysis_moderators:
+                data_collector.collect(analysis_moderator.parameters)
+
         if cluster is not None:
             cluster.set_project_path(self.base_folder)
             cluster.read_configuration()
