@@ -475,6 +475,11 @@ class RelativeFreeInstrumentParameter(FreeInstrumentParameter):
             List of values that will be used as constants in the function
         """
         for dependent in make_list(dependent_on):
+            if not isinstance(dependent_on, InstrumentParameter):
+                print("Following object given as dependent_on is not supported:")
+                print(dependent_on)
+                raise RuntimeError("Given parameter is not an InstrumentParameter")
+
             self.all_dependent_on.add(dependent.name)
 
         # Set up a dynamic illegal interval with function for upper and lower limit
