@@ -533,7 +533,8 @@ class Sample:
 
         return 2*self["div_horizontal"], 2*self["div_vertical"]
 
-    def perform_analysis(self, instrument, instrument_brill_ref, parameters, settings):
+    def perform_analysis(self, instrument, instrument_brill_ref, parameters,
+                         settings):
         """
         Performs analysis of the optimized guide using McStasScript
 
@@ -564,8 +565,13 @@ class Sample:
             Settings for running simulation, optional to use these
         """
 
+        # Snapshot width can be given in settings, float with unit [AA]
+        if "snapshot_widths" in settings:
+            snapshot_widths = settings["snapshot_widths"]
+        else:
+            snapshot_widths = 0.01
+
         snapshot_centers = np.linspace(self["min_wavelength"], self["max_wavelength"], 3)
-        snapshot_widths = 0.01
 
         snapshot_minimums = snapshot_centers - 0.5 * snapshot_widths
         snapshot_maximums = snapshot_centers + 0.5 * snapshot_widths
@@ -584,10 +590,11 @@ class Sample:
             self.plot_info.apply_all_data(sim_data)
             #self.plot_info.apply_all_data(ref_data) # Doesnt handle case where not all found
 
-            plotter.make_sub_plot(sim_data[0:6], filename=name + "_1.png")
-            plotter.make_sub_plot(sim_data[6:11], filename=name + "_2.png")
-            plotter.make_sub_plot(sim_data[11:], filename=name + "_3.png")
-            plotter.make_sub_plot(ref_data, filename=name + "_ref.png")
+            if sim_data is not None:
+                plotter.make_sub_plot(sim_data[0:6], filename=name + "_1.png")
+                plotter.make_sub_plot(sim_data[6:11], filename=name + "_2.png")
+                plotter.make_sub_plot(sim_data[11:], filename=name + "_3.png")
+                plotter.make_sub_plot(ref_data, filename=name + "_ref.png")
 
         name = "large_wavelength_band"
         parameters["min_wavelength"] = 0.5 * self["min_wavelength"]
@@ -601,10 +608,11 @@ class Sample:
         self.plot_info.apply_all_data(sim_data)
         #self.plot_info.apply_all_data(ref_data) # Doesnt handle case where not all found
 
-        plotter.make_sub_plot(sim_data[0:6], filename=name + "_1.png")
-        plotter.make_sub_plot(sim_data[6:11], filename=name + "_2.png")
-        plotter.make_sub_plot(sim_data[11:], filename=name + "_3.png")
-        plotter.make_sub_plot(ref_data, filename=name + "_ref.png")
+        if sim_data is not None:
+            plotter.make_sub_plot(sim_data[0:6], filename=name + "_1.png")
+            plotter.make_sub_plot(sim_data[6:11], filename=name + "_2.png")
+            plotter.make_sub_plot(sim_data[11:], filename=name + "_3.png")
+            plotter.make_sub_plot(ref_data, filename=name + "_ref.png")
 
         name = "fom_wavelength_band"
         parameters["min_wavelength"] = self["min_wavelength"]
@@ -619,10 +627,11 @@ class Sample:
         self.plot_info.apply_all_data(sim_data)
         # self.plot_info.apply_all_data(ref_data) # Doesnt handle case where not all found
 
-        plotter.make_sub_plot(sim_data[0:6], filename=name + "_1.png")
-        plotter.make_sub_plot(sim_data[6:11], filename=name + "_2.png")
-        plotter.make_sub_plot(sim_data[11:], filename=name + "_3.png")
-        plotter.make_sub_plot(ref_data, filename=name + "_ref.png")
+        if sim_data is not None:
+            plotter.make_sub_plot(sim_data[0:6], filename=name + "_1.png")
+            plotter.make_sub_plot(sim_data[6:11], filename=name + "_2.png")
+            plotter.make_sub_plot(sim_data[11:], filename=name + "_3.png")
+            plotter.make_sub_plot(ref_data, filename=name + "_ref.png")
 
 
 class PlotInfo:
@@ -760,6 +769,9 @@ class PlotInfoContainer:
         return info
 
     def apply_all_data(self, data):
+        if data is None:
+            return
+
         for info in self.infos:
             info.apply_to_data(data)
 
@@ -823,7 +835,7 @@ def run_simulation_brill(name, parameters, settings, instrument):
         ncount = 10*settings["ncount"]
 
     reduced_parameters = {}
-    for parameter in instrument.parameter_list:
+    for parameter in list(instrument.parameters):
         if parameter.name in parameters:
             reduced_parameters[parameter.name] = parameters[parameter.name]
 
@@ -868,6 +880,9 @@ def normalize_brill_ref(data, ref_data, instrument, ref_instrument):
     for data_object in ref_data:
         ref_data_names.append(data_object.name)
 
+    if data is None:
+        return None
+
     normalized_monitors = []
     for data_object in data:
         if data_object.name in ref_data_names:
