@@ -359,7 +359,7 @@ class BaseSource:
         Adds GuideElement to Guide describing what is between source and guide
 
         In most cases there is just a Gap between the source and the guide,
-        which is what will be insterted from the BaseSource. One could imagine
+        which is what will be inserted from the BaseSource. One could imagine
         sources with some other element, perhaps reflector parts, that can be
         added. These can be optimized or have fixed values as if they were
         provided by the user.
@@ -377,6 +377,21 @@ class BaseSource:
         start_gap = Element_gap.Gap(name="moderator_guide_gap", start_width=self["width"], start_height=self["height"])
         guide.add_guide_element_at_start(start_gap)
 
+    def set_data_path(self, data_folder_path):
+        self.data_folder_path = data_folder_path
+
+    def copy_data_file(self, file_path):
+
+        assert os.path.exists(file_path)
+
+        file_name = os.path.split(file_path)[1]
+        destination_path = os.path.join(self.data_folder_path, file_name)
+        if os.path.exists(destination_path):
+            # datafile already in data folder
+            return
+
+        shutil.copyfile(file_path, destination_path)
+
 
 class Moderator(BaseSource):
     """
