@@ -43,8 +43,9 @@ class Parameters:
         self.prefix = ""
 
         self.parameter_units = {}
+        self.parameter_is_filename = {}
 
-    def add(self, name, value, unit=None):
+    def add(self, name, value, unit=None, is_filename=False):
         """
         Add new parameter, either with fixed value or scanned with list
 
@@ -65,6 +66,9 @@ class Parameters:
 
         unit : str
             Unit for the parameter, used in plotting
+
+        is_filename : bool
+            Set to True if this is a path to a file that is needed for simulation
         """
         name = self.prefix + name
 
@@ -78,6 +82,8 @@ class Parameters:
         else:
             try:
                 n_points = len(value)
+                if n_points == 1:
+                    self.parameters[name] = value[0]
             except:
                 raise RuntimeError("Parameters have to be int, float "
                                    + "str or array with len specified.")
@@ -88,6 +94,7 @@ class Parameters:
             self.scanned_parameters.append(name)
         
         self.parameter_units[name] = str(unit)
+        self.parameter_is_filename[name] = bool(is_filename)
 
     def get_n_scanned_parameters(self):
         """
@@ -188,6 +195,18 @@ class Parameters:
 
         return unit_dict
 
+    def get_filename_pars(self):
+        """
+        Get list of parameter names that correspond til filenames
+        """
+
+        filename_par_names = []
+        for name, is_file in self.parameter_is_filename.items():
+            if is_file:
+                filename_par_names.append(name)
+
+        return filename_par_names
+
     def get_current_scan_state(self):
         """
         Gets a dictionary of current state of parameters
@@ -228,7 +247,7 @@ class Parameters:
         """
         name = self.prefix + name
         if name not in self.parameters:
-            raise KeyError("Parameter named " + name + " not available")
+            raise KeyError("Parameter named " + name + " not defined.")
 
         if name in self.lock_map:
             scan_name = self.lock_map[name]
@@ -243,6 +262,40 @@ class Parameters:
         else:
             return self.parameters[name]
 
+    def __setitem__(self, name, value):
+        """
+        Allow setting a parameter taking current state into account
+
+        This method allows a user to update a parameter taking the current
+        scan state into account.
+
+        Parameters
+        ----------
+
+        name : str
+            Name of the parameter for which the current value should be updated
+
+        value
+            New value for this parameter and current scan state
+        """
+
+        name = self.prefix + name
+        if name not in self.parameters:
+            raise KeyError("Parameter named " + name + " not available")
+
+        if name in self.lock_map:
+            scan_name = self.lock_map[name]
+        else:
+            scan_name = name
+
+        if scan_name in self.scanned_parameters:
+            par_index = self.scanned_parameters.index(scan_name)
+            scan_index = self.state[par_index]
+            array = self.parameters[name]
+            array[scan_index] = value
+        else:
+            self.parameters[name] = value
+
     def print_current_state(self):
         """
         Prints the current value of all parameters based on the current state
