@@ -30,6 +30,7 @@ class PlotGuideGeometry(BaseInterface):
 
         self.last_log_plotter = None
         self.last_guide = None
+        self.last_moderator = None
         self.last_indices = None
 
         self.sample_scan_labels = None
@@ -37,7 +38,6 @@ class PlotGuideGeometry(BaseInterface):
 
         self.selected_guide = self.guides_with_at_least_one_run[0]
 
-
     def set_guide(self, guide):
         if guide not in self.get_guide_names():
             raise KeyError("Need to select a guide available in the dataset!")
@@ -77,18 +77,27 @@ class PlotGuideGeometry(BaseInterface):
 
         guide = self.selected_guide
         indices = tuple(self.list_indicies)
-        #moderator = self.moderator
+        moderator = self.moderator
         #run_name = self.run_name
         #monitor = self.monitor
 
-        if self.last_guide == guide and self.last_indices == indices:
+        if self.last_guide == guide and self.last_indices == indices and self.last_moderator == moderator:
             return self.last_log_plotter
 
         log_plotter = None
-        if self.scan_overview.log[guide][indices]["log"] is not None:
-            log_plotter = LogPlotter(self.scan_overview.log[guide][indices]["log"])
+        log_moderator = moderator
+        if self.scan_overview.get_moderators()[0] == moderator:
+            log_moderator = "main"
+
+        log = self.scan_overview.log[guide][indices][log_moderator]["log"]
+        guide_log = self.scan_overview.log[guide][indices][log_moderator]["guide_log"]
+
+        if log is not None and guide_log is not None:
+            log_plotter = LogPlotter(log, guide_log)
+
             self.last_guide = guide
             self.last_indices = indices
+            self.last_moderator = moderator
             self.last_log_plotter = log_plotter
 
         n_foms = len(log_plotter.data_fom_sorted[:, 0])
